![Swarmauri Logo](https://github.com/swarmauri/swarmauri-sdk/blob/3d4d1cfa949399d7019ae9d8f296afba773dfb7f/assets/swarmauri.brand.theme.svg)

<p align="center">
    <a href="https://pypi.org/project/cayaml/">
        <img src="https://img.shields.io/pypi/dm/cayaml" alt="PyPI - Downloads"/></a>
    <a href="https://hits.sh/github.com/swarmauri/swarmauri-sdk/tree/master/pkgs/experimental/cayaml/">
        <img alt="Hits" src="https://hits.sh/github.com/swarmauri/swarmauri-sdk/tree/master/pkgs/experimental/cayaml.svg"/></a>
    <a href="https://pypi.org/project/cayaml/">
        <img src="https://img.shields.io/pypi/pyversions/cayaml" alt="PyPI - Python Version"/></a>
    <a href="https://pypi.org/project/cayaml/">
        <img src="https://img.shields.io/pypi/l/cayaml" alt="PyPI - License"/></a>
    <a href="https://pypi.org/project/cayaml/">
        <img src="https://img.shields.io/pypi/v/cayaml?label=cayaml&color=green" alt="PyPI - cayaml"/></a>

</p>

---

